@@ -203,7 +203,7 @@ class Modifier(db.Model, AutoID, Timestamped, AutoName):
 
     def __repr__(self):
         return ("{x.__class__.__name__}({x.request}, {x.user},"
-                "{x.pretty_value}, {x.voided})".format(x=self, value=self))
+                "{x}, {x.voided})".format(x=self, value=self))
 
     def void(self, user):
         """Mark this modifier as void.
@@ -414,6 +414,8 @@ class Request(db.Model, AutoID, Timestamped, AutoName):
             ActionType.incomplete: (PermissionType.review,),
             ActionType.rejected: (PermissionType.review,),
             ActionType.approved: (PermissionType.review,),
+            ActionType.evaluating: (PermissionType.review,
+                PermissionType.submit),
         },
         ActionType.incomplete: {
             ActionType.rejected: (PermissionType.review,),
@@ -433,6 +435,14 @@ class Request(db.Model, AutoID, Timestamped, AutoName):
         },
     }
 
+    def valid_actions(self, user):
+        """Get valid actions (besides comment) the given user can perform."""
+        possible_actions = self.state_rules[self.status]
+        def action_filter(action):
+            return user.has_permission(possible_actions[action],
+                    self.division)
+        return filter(action_filter, possible_actions)
+
     @db.validates('status')
     def validate_status(self, attr, new_status):
         """Enforces that status changes follow the status state diagram below.
@@ -526,3 +536,26 @@ class Request(db.Model, AutoID, Timestamped, AutoName):
                 self.division):
             raise ModifierError("Only reviewers can add modifiers.")
         return modifier
+
+    @property
+    def transformed(self):
+        """Get a special HTML representation of an attribute.
+
+        Divisions can have a transformer defined on a for attributes that
+        output a URL associated with that attribute. This property provides
+        easy access to the output of any transformed attributes on this
+        request.
+        """
+        class RequestTransformer(object):
+            def __getattr__(self, attr):
+                raw_value = getattr(self._request, attr)
+                if attr in self._request.division.transformers:
+                    transformer = self._request.division.transformers[attr]
+                    return Markup('<a href="{link}">{value}</a>').format(
+                            link=transformer(raw_value), value=str(raw_value))
+                else:
+                    return raw_value
+
+            def __init__(self, request):
+                self._request = request
+        return RequestTransformer(self)
